@@ -42,6 +42,7 @@
 #include <linux/config.h>
 #include <linux/module.h>
 #include <linux/version.h>
+#include <linux/modversions.h>
 #include <linux/sched.h>
 #include <linux/errno.h>
 #include <linux/kernel.h>
@@ -117,7 +118,7 @@ static struct scanner_capabilities scc_logi32={
 	1				/* 1 option (Dithering) */
 };
 
-static struct scanner_option opt_logi32[1]={SCC_HARDSWITCH,"Dithering"};
+static struct scanner_option opt_logi32[1]={{SCC_HARDSWITCH,"Dithering"}};
 
 static struct scanner_capabilities scc_logi256={
 
@@ -163,7 +164,9 @@ int LOGI_DMA   =LOGI32_DMA;
 
 /* End of exported variables */
 
+#if OLD_KERNEL
 char kernel_version[]=KERNEL_VERSION;	/* needed for module installer */
+#endif
 
 /************************************************************************/
 
@@ -569,9 +572,9 @@ static int refill_buffer(void)
                               copy_buffer[x]=0;
             		    for(x=0;x<hw_modeinfo.bpl;x++) 
                             { copy_buffer[x>>2]|=
-                                (RD_ADDR[x]&0xf0>0x70) ? bitmask[(x+x  )&7] : 0;
+                                ((RD_ADDR[x]&0xf0)>0x70) ? bitmask[(x+x  )&7] : 0;
 			      copy_buffer[(x>>2)+1]|=
-                                (RD_ADDR[x]&0x0f>0x07) ? bitmask[(x+x+1)&7] : 0;
+                                ((RD_ADDR[x]&0x0f)>0x07) ? bitmask[(x+x+1)&7] : 0;
                             }
                             inbuffer=x>>2;
                             break;
@@ -707,7 +710,7 @@ static int logi32_select(struct inode *inode, struct file *file, \
   return 0;
 }
 
-static void logi32_interrupt(int irq,struct pt_regs *unused)
+static void logi32_interrupt(int irq, void *dev_id, struct pt_regs *unused)
 {
   static int bytes_til_wakeup;
   int help;
@@ -1010,11 +1013,12 @@ static int logi32_open(struct inode *inode, struct file *file)
 
   logi32_get_mode(); 
 
-  if((r=request_irq(LOGI_IRQ, logi32_interrupt, SA_INTERRUPT, LOGI32_SCANNER_NAME )))	/* request IRQ */
+  if((r=request_irq(LOGI_IRQ, logi32_interrupt, SA_INTERRUPT, 
+  		    LOGI32_SCANNER_NAME, LOGI32_SCANNER_NAME )))	/* request IRQ */
     return r;
 
   if((r=request_dma(LOGI_DMA, LOGI32_SCANNER_NAME))) {
-    free_irq(LOGI_IRQ);
+    free_irq(LOGI_IRQ, LOGI32_SCANNER_NAME);
     return r;
   }
 
@@ -1032,7 +1036,7 @@ static void logi32_close(struct inode *inode, struct file *file)
     logi32_free_mem();
   inbuffer=0;
   free_dma(LOGI_DMA);
-  free_irq(LOGI_IRQ);
+  free_irq(LOGI_IRQ, LOGI32_SCANNER_NAME);
   ds.device_open = 0;
   MOD_DEC_USE_COUNT;
 }
